@@ -1,6 +1,6 @@
 from pathlib import Path
 import subprocess
-from typing import List, Optional
+from typing import List, Optional, Union
 
 from .reply.api import REPLY_API
 
@@ -8,11 +8,15 @@ from .reply.api import REPLY_API
 class CMakeProject(object):
     __slots__ = ("_source_path", "_build_path", "_api_version", "_cmake")
 
-    def __init__(self, build_path: Path, source_path: Optional[Path]=None, api_version: Optional[int]=None, cmake: Optional[str]=None):
+    def __init__(self, build_path: Union[Path, str], source_path: Optional[Union[Path, str]]=None, api_version: Optional[int]=None, cmake: Optional[str]=None):
         if not build_path:
             raise ValueError("Need a build folder")
-        self._source_path = Path(source_path) if source_path else None
-        self._build_path = Path(build_path)
+        if isinstance(source_path, str):
+            source_path = Path(source_path).resolve()
+        self._source_path = source_path.resolve()
+        if isinstance(build_path, str):
+            build_path = Path(build_path).resolve()
+        self._build_path = build_path
         self._api_version = api_version if api_version is not None else self.most_recent_api_version()
         self._cmake = cmake or "cmake"
 
